@@ -27,6 +27,7 @@ use serde::Serialize;
 use std::borrow::Cow;
 use std::cell::RefCell;
 use std::fmt;
+use std::path::PathBuf;
 use std::usize;
 
 use crate::blob::op_blob_create_object_url;
@@ -352,6 +353,10 @@ fn op_encoding_encode_into(
   })
 }
 
+pub fn get_declaration() -> PathBuf {
+  PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("lib.deno_web.d.ts")
+}
+
 #[derive(Debug)]
 pub struct DomExceptionQuotaExceededError {
   pub msg: String,
